@@ -9,7 +9,9 @@ use crate::server::RequestExt;
 pub async fn proxy(req: Request<Body>, format: &str) -> Result<Response<Body>, String> {
 	let mut url = format!("{}?{}", format, req.uri().query().unwrap_or_default());
 
+	// For each parameter in request
 	for (name, value) in req.params().iter() {
+		// Fill the parameter value in the url
 		url = url.replace(&format!("{{{}}}", name), value);
 	}
 
@@ -29,14 +31,13 @@ async fn stream(url: &str, req: &Request<Body>) -> Result<Response<Body>, String
 	let mut builder = Request::get(url);
 
 	// Copy useful headers from original request
-	let headers = req.headers();
 	for &key in &["Range", "If-Modified-Since", "Cache-Control"] {
-		if let Some(value) = headers.get(key) {
+		if let Some(value) = req.headers().get(key) {
 			builder = builder.header(key, value);
 		}
 	}
 
-	let stream_request = builder.body(Body::default()).expect("stream");
+	let stream_request = builder.body(Body::empty()).map_err(|_| "Couldn't build empty body in stream".to_string())?;
 
 	client
 		.request(stream_request)
@@ -60,13 +61,14 @@ async fn stream(url: &str, req: &Request<Body>) -> Result<Response<Body>, String
 		.map_err(|e| e.to_string())
 }
 
-fn request(url: String) -> Boxed<Result<Response<Body>, String>> {
+fn request(url: String, quarantine: bool) -> Boxed<Result<Response<Body>, String>> {
 	// Prepare the HTTPS connector.
 	let https = hyper_rustls::HttpsConnector::with_native_roots();
 
-	// Build the hyper client from the HTTPS connector.
+	// Construct the hyper client from the HTTPS connector.
 	let client: client::Client<_, hyper::Body> = client::Client::builder().build(https);
 
+	// Build request
 	let builder = Request::builder()
 		.method("GET")
 		.uri(&url)
@@ -75,6 +77,7 @@ fn request(url: String) -> Boxed<Result<Response<Body>, String>> {
 		.header("Accept", "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8")
 		.header("Accept-Language", "en-US,en;q=0.5")
 		.header("Connection", "keep-alive")
+		.header("Cookie", if quarantine { "_options=%7B%22pref_quarantine_optin%22%3A%20true%7D" } else { "" })
 		.body(Body::empty());
 
 	async move {
@@ -89,6 +92,7 @@ fn request(url: String) -> Boxed<Result<Response<Body>, String>> {
 								.map(|val| val.to_str().unwrap_or_default())
 								.unwrap_or_default()
 								.to_string(),
+							quarantine,
 						)
 						.await
 					} else {
@@ -105,7 +109,7 @@ fn request(url: String) -> Boxed<Result<Response<Body>, String>> {
 
 // Make a request to a Reddit API and parse the JSON response
 #[cached(size = 100, time = 30, result = true)]
-pub async fn json(path: String) -> Result<Value, String> {
+pub async fn json(path: String, quarantine: bool) -> Result<Value, String> {
 	// Build Reddit url from path
 	let url = format!("https://www.reddit.com{}", path);
 
@@ -116,7 +120,7 @@ pub async fn json(path: String) -> Result<Value, String> {
 	};
 
 	// Fetch the url...
-	match request(url.clone()).await {
+	match request(url.clone(), quarantine).await {
 		Ok(response) => {
 			// asynchronously aggregate the chunks of the body
 			match hyper::body::aggregate(response).await {
